package com.ruoyi.doubledefense.service;

import java.util.List;

import com.github.pagehelper.PageInfo;
import com.ruoyi.doubledefense.domain.RiskEvent;
import com.ruoyi.doubledefense.dto.RiskEventDTO;
import com.ruoyi.doubledefense.dto.res.RiskEventResultDTO;
import com.ruoyi.doubledefense.dtoGov.RiskEventDTOGov;

/**
 * 风险事件Service接口
 *
 * @author ruoyi
 * @date 2023-08-03
 */
public interface IRiskEventService
{

    /**
     * 重预防汇聚计算节点
     * 查询风险事件
     * @param riskEvent
     * @return
     */
    PageInfo<RiskEventDTOGov> govSelectRiskEventList(RiskEventDTOGov riskEvent);

    /**
     * 查询风险事件
     *
     * @param id 风险事件主键
     * @return 风险事件
     */
    public RiskEventResultDTO selectRiskEventById(String id);

    /**
     * 查询风险事件列表
     *
     * @param riskEvent 风险事件
     * @return 风险事件集合
     */
    public List<RiskEventResultDTO> selectRiskEventList(RiskEventDTO riskEvent);

    /**
     * 新增风险事件
     *
     * @param riskEvent 风险事件
     * @return 结果
     */
    public int insertRiskEvent(RiskEventDTO riskEvent);

    /**
     * 修改风险事件
     *
     * @param riskEvent 风险事件
     * @return 结果
     */
    public int updateRiskEvent(RiskEventDTO riskEvent);

    /**
     * 批量删除风险事件
     *
     * @param ids 需要删除的风险事件主键集合
     * @return 结果
     */
    public int deleteRiskEventByIds(String[] ids);

}
